/**
 * Converts an array of nodes which have an id and their children's ids, to a tree.
 * The root is the node with the id `rootId`. If it doesn't exist return null.
 */
function buildTree(arrayNodes, rootId) {
    if (!arrayNodes.some(({ id }) => id === rootId))
        return null;
    const idToArrayNode = {};
    arrayNodes.forEach((node) => { idToArrayNode[node.id] = node; });
    return internalBuildTree(idToArrayNode, rootId);
}
function internalBuildTree(idToArrayNode, rootId) {
    const rootNode = idToArrayNode[rootId];
    return !rootNode.children ? rootNode : {
        ...rootNode,
        ...{ children: rootNode.children.map((id) => internalBuildTree(idToArrayNode, id)) },
    };
}

export default buildTree;
