import 'cross-fetch/polyfill';
import { Id } from './api-types';
import { PreferenceKey } from './api-types/account-level';
import { VersionNumber } from './api-types/document-level';
import * as DC from './api-types/document-level/changes';
import * as FC from './api-types/file-level/changes';
import * as P from './api-types/request-parameters';
import * as PR from './api-types/responses/parameterized';
export default class Client {
    private token;
    /** @param token Your API secret token. */
    constructor(token: string);
    /** Lists all your documents and folders. */
    listDocumentsAndFolders(): Promise<import("./api-types/responses/helpers").CommonResponse<{
        root_file_id: string;
        files: import("./api-types/file-level").File[];
    }>>;
    /** Changes (moves, edits or creates) specific documents and folders. */
    changeDocumentsAndFolders(changes: readonly FC.FileLevelChange[]): Promise<import("./api-types/responses/helpers").CommonResponse<{
        results: boolean[];
        created: string[];
    }>>;
    moveDocumentOrFolder(moveParams: FC.FileLevelMoveParams): FileLevelMoveOrEditResult;
    editDocumentOrFolder(editParams: FC.FileLevelEditParams): FileLevelMoveOrEditResult;
    createDocumentOrFolder(createParams: FC.FileLevelCreateParams): FileLevelCreateResult;
    /** Fetches the content of a specific document. */
    readDocument(documentId: Id): Promise<PR.ParameterizedDocReadResponse<{
        file_id: string;
        title: string;
        version: number;
        nodes: import("./api-types/document-level").Node[];
    }>>;
    /** Fetches the latest version numbers of specific documents. */
    fetchDocumentsVersionNumbers<T extends readonly Id[]>(documentIds: T): Promise<import("./api-types/responses/helpers").CommonResponseWithoutLockFail<{
        versions: Partial<Record<T[number], number>>;
    }>>;
    /** Fetches the latest version number of a specific document. */
    fetchDocumentVersionNumber(documentId: Id): FetchDocumentVersionNumberResult;
    /** Changes the content (inserts, edits, moves or deletes nodes) of a specific document. */
    changeDocumentContent(documentId: Id, changes: readonly DC.DocumentLevelChange[]): Promise<PR.ParameterizedDocEditResponse<{
        new_node_ids: string[];
    }>>;
    insertNode(documentId: Id, insertParams: DC.DocumentLevelInsertParams): DocumentLevelInsertResult;
    editNode(documentId: Id, editParams: DC.DocumentLevelEditParams): DocumentLevelChangeEmptyResult;
    moveNode(documentId: Id, moveParams: DC.DocumentLevelMoveParams): DocumentLevelChangeEmptyResult;
    deleteNode(documentId: Id, deleteParams: DC.DocumentLevelDeleteParams): DocumentLevelChangeEmptyResult;
    /** Adds a node to your inbox. */
    addToInbox(params: P.InboxAddRequestParameters): Promise<PR.ParameterizedInboxAddResponse<{
        file_id: string;
        node_id: string;
        index: number;
    }>>;
    /** Uploads a file. (Pro only) */
    uploadFile(params: P.UploadRequestParameters): Promise<PR.ParameterizedUploadResponse<{
        url: string;
    }>>;
    /** Gets a user preference value. */
    getPreference<T extends PreferenceKey>(preferenceKey: T): Promise<import("./api-types/responses/helpers").CommonResponseWithoutLockFail<{
        key: T;
        value: import("./api-types/account-level").Preferences[T];
    }>>;
    /** Sets a user preference value. */
    setPreference<T extends PreferenceKey>(params: P.PrefSetRequestParameters<T>): Promise<import("./api-types/responses/helpers").CommonResponseWithoutLockFail<{}>>;
    private changeDocumentOrFolder;
    private makeOneNodeChange;
    private requestEndpoint;
}
declare type FileLevelMoveOrEditResult = Promise<PR.ParameterizedFileEditResponse<{
    succeeded: boolean;
}>>;
declare type FileLevelCreateResult = Promise<PR.ParameterizedFileEditResponse<{
    created_file_id?: Id;
}>>;
declare type FetchDocumentVersionNumberResult = Promise<PR.ParameterizedDocCheckForUpdatesResponse<{
    version?: VersionNumber;
}>>;
declare type DocumentLevelInsertResult = Promise<PR.ParameterizedDocEditResponse<{
    new_node_id: Id;
}>>;
declare type DocumentLevelChangeEmptyResult = Promise<PR.ParameterizedDocEditResponse<{}>>;
export {};
